==> haskell-floatinghex-0.5-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-floatinghex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 FloatingHex
version:              0.5
visibility:           public
id:                   FloatingHex-0.5-7pijLrWv68I61QKVSLlVAY
key:                  FloatingHex-0.5-7pijLrWv68I61QKVSLlVAY
license:              BSD-3-Clause
copyright:            Levent Erkok
maintainer:           erkokl@gmail.com
author:               Levent Erkok
synopsis:             Read and write hexadecimal floating point numbers
description:
    Read and write hexadecimal floating point numbers. Provides a quasiquoter for
    entering hex-float literals, and a function for printing them in hexadecimal.

    See: <http://www.open-std.org/jtc1/sc22/wg14/www/docs/n1256.pdf>, pages 57-58.
    We slightly diverge from the standard and do not allow for the "floating-suffix,"
    as the type inference of Haskell makes this unnecessary.

    For details, please see: <http://github.com/LeventErkok/FloatingHex/>

category:             Tools
abi:                  75b68949536c2637741c38ffd41233ed
exposed:              True
exposed-modules:      Data.Numbers.FloatingHex
import-dirs:          /usr/lib/ghc-9.0.1/site-local/FloatingHex-0.5
library-dirs:         /usr/lib/ghc-9.0.1/site-local/FloatingHex-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/FloatingHex-0.5
hs-libraries:         HSFloatingHex-0.5-7pijLrWv68I61QKVSLlVAY
depends:              base-4.15.0.0 template-haskell-2.17.0.0
haddock-interfaces:   /usr/share/doc/haskell-floatinghex/html/FloatingHex.haddock
haddock-html:         /usr/share/doc/haskell-floatinghex/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-floatinghex-0.5-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-floatinghex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 FloatingHex
version:              0.5
visibility:           public
id:                   FloatingHex-0.5-LDkK4EXDDRM9ZfzX9IrabI
key:                  FloatingHex-0.5-LDkK4EXDDRM9ZfzX9IrabI
license:              BSD-3-Clause
copyright:            Levent Erkok
maintainer:           erkokl@gmail.com
author:               Levent Erkok
synopsis:             Read and write hexadecimal floating point numbers
description:
    Read and write hexadecimal floating point numbers. Provides a quasiquoter for
    entering hex-float literals, and a function for printing them in hexadecimal.

    See: <http://www.open-std.org/jtc1/sc22/wg14/www/docs/n1256.pdf>, pages 57-58.
    We slightly diverge from the standard and do not allow for the "floating-suffix,"
    as the type inference of Haskell makes this unnecessary.

    For details, please see: <http://github.com/LeventErkok/FloatingHex/>

category:             Tools
abi:                  e2e3404f246deda95b99549c452bcdd0
exposed:              True
exposed-modules:      Data.Numbers.FloatingHex
import-dirs:          /usr/lib/ghc-9.0.2/site-local/FloatingHex-0.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/FloatingHex-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/FloatingHex-0.5
hs-libraries:         HSFloatingHex-0.5-LDkK4EXDDRM9ZfzX9IrabI
depends:              base-4.15.1.0 template-haskell-2.17.0.0
haddock-interfaces:   /usr/share/doc/haskell-floatinghex/html/FloatingHex.haddock
haddock-html:         /usr/share/doc/haskell-floatinghex/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
